#[repr(C)]pub struct DispatchCommand {
pub x: u32,
pub y: u32,
pub z: u32,
}Expand description
Draw command for dispatch.
Fields
x: u32Number of local workgroups to dispatch in the X dimension.
y: u32Number of local workgroups to dispatch in the Y dimension.
z: u32Number of local workgroups to dispatch in the Z dimension.