Level

Trait Level 

pub trait Level:
    Copy
    + Default
    + Debug
    + 'static {
    // Required method
    fn raw_level(&self) -> Level;
}
Type-level buffer level flag. It defines whether buffer can be submitted to the command queues or executed as part of the primary buffers.

Required Methods

fn raw_level(&self) -> Level

Get raw level value for command buffer allocation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors